# -*- encoding: utf-8 -*-
require 'omniauth-oauth2'

module OmniAuth
  module Strategies
    class Jd < OmniAuth::Strategies::OAuth2
      option :name, 'jd'
      option :client_options, {
                 site: "https://auth.360buy.com", # 
        authorize_url: "/oauth/authorize",
            token_url: "/oauth/token"
      }
      option :token_params, {
        :parse => :json
      }

      uid do
        raw_info['vender_id']
      end

      info do
        {
          nickname: raw_info['shop_name']
        }
      end

      extra do
        {
          raw_info: raw_info
        }
      end

      def raw_info
        access_token.options[:mode] = :query
        @raw_info ||= access_token.get('http://gw.api.360buy.com/routerjson', params: signed_params, parse: :json).parsed['jingdong_vender_shop_query_responce']['shop_jos_result'] rescue {}
      end

      private
      
      def params
        {
          method: 'jingdong.vender.shop.query',
          access_token: access_token.token,
          app_key: client.id,
          timestamp: timestamp,
          v: '2.0'
        }
      end

      def signed_params
         rand = client.secret + params.sort.flatten.join + client.secret
        token = Digest::MD5.hexdigest(rand).upcase
        params.merge(sign: token)# 數字簽名
      end

      def timestamp # 时间戳
        Time.now.strftime("%Y-%m-%d %H:%M:%S")
      end
    end
  end
end

OmniAuth.config.add_camelization "jd", "Jd"